@@ -26,10 +26,9 @@
 #include <limits>
 #include <sstream>
 
-#include <QDateTime>
-
 #include "BrainModelSurface.h"
 #include "BrainModelSurfaceMetricKruskalWallisRankTest.h"
+#include "DateAndTime.h"
 #include "FileUtilities.h"
 #include "MetricFile.h"
 #include "StatisticKruskalWallis.h"
@@ -381,7 +380,8 @@ BrainModelSurfaceMetricKruskalWallisRankTest::executeClusterSearch() throw (Brai
       //
       // Show area and thresholds
       //
-      reportStream << "Date/Time:           " << QDateTime::currentDateTime().toString("MMM d, yyyy hh:mm:ss") << "\n";
+      reportStream << "Date/Time:           " << DateAndTime::getDateAndTimeAsString() << "\n";
+                       //QDateTime::currentDateTime().toString("MMM d, yyyy hh:mm:ss") << "\n";
       for (int m = 0; m < numInputFiles; m++) {
       reportStream << "Shape File :         " << inputMetricFileNames[m] << "\n";
       }
