@@ -27,7 +27,6 @@
 #include <limits>
 #include <sstream>
 
-#include <QDateTime>
 #include <QFile>
 #include <QTextStream>
 
@@ -35,6 +34,7 @@
 #include "BrainModelSurfaceMetricOneAndPairedTTest.h"
 #include "BrainSet.h"
 #include "CoordinateFile.h"
+#include "DateAndTime.h"
 #include "DebugControl.h"
 #include "FileUtilities.h"
 #include "PaintFile.h"
@@ -349,7 +349,8 @@ BrainModelSurfaceMetricOneAndPairedTTest::executeClusterSearch() throw (BrainMod
    //
    // Show area and thresholds
    //
-   reportStream << "Date/Time:           " << QDateTime::currentDateTime().toString("MMM d, yyyy hh:mm:ss") << "\n";
+   reportStream << "Date/Time:           " << DateAndTime::getDateAndTimeAsString() << "\n";
+                       //QDateTime::currentDateTime().toString("MMM d, yyyy hh:mm:ss") << "\n";
    reportStream << "Metric/Shape:        " << metricFileNames[0] << "\n";
    switch (tTestMode) {
       case T_TEST_MODE_ONE_SAMPLE:
